Icentia11k Single Lead Continuous Raw Electrocardiogram Dataset v1.0
Description: This is a dataset of continuous raw electrocardiogram (ECG) signals for representation learning containing 11 thousand patients and 2 billion labelled beats.

Database Open Access

# Icentia11k Single Lead Continuous Raw Electrocardiogram Dataset

Shawn Tan , Satya Ortiz-Gagné , Nicolas Beaudoin-Gagnon , Pierre Fecteau , Aaron Courville , Yoshua Bengio , Joseph Paul Cohen

Published: April 12, 2022. Version: 1.0

When using this resource, please cite: (show more options)
Tan, S., Ortiz-Gagné, S., Beaudoin-Gagnon, N., Fecteau, P., Courville, A., Bengio, Y., & Cohen, J. P. (2022). Icentia11k Single Lead Continuous Raw Electrocardiogram Dataset (version 1.0). PhysioNet. https://doi.org/10.13026/kk0v-r952.

##### Cite

MLA | Tan, Shawn, et al. "Icentia11k Single Lead Continuous Raw Electrocardiogram Dataset" (version 1.0). PhysioNet (2022), https://doi.org/10.13026/kk0v-r952.
APA | Tan, S., Ortiz-Gagné, S., Beaudoin-Gagnon, N., Fecteau, P., Courville, A., Bengio, Y., & Cohen, J. P. (2022). Icentia11k Single Lead Continuous Raw Electrocardiogram Dataset (version 1.0). PhysioNet. https://doi.org/10.13026/kk0v-r952.
Chicago | Tan, Shawn, Ortiz-Gagné, Satya, Beaudoin-Gagnon, Nicolas, Fecteau, Pierre, Courville, Aaron, Bengio, Yoshua, and Joseph Paul Cohen. "Icentia11k Single Lead Continuous Raw Electrocardiogram Dataset" (version 1.0). PhysioNet (2022). https://doi.org/10.13026/kk0v-r952.
Harvard | Tan, S., Ortiz-Gagné, S., Beaudoin-Gagnon, N., Fecteau, P., Courville, A., Bengio, Y., and Cohen, J. P. (2022) 'Icentia11k Single Lead Continuous Raw Electrocardiogram Dataset' (version 1.0), PhysioNet. Available at: https://doi.org/10.13026/kk0v-r952.
Vancouver | Tan S, Ortiz-Gagné S, Beaudoin-Gagnon N, Fecteau P, Courville A, Bengio Y, Cohen J P. Icentia11k Single Lead Continuous Raw Electrocardiogram Dataset (version 1.0). PhysioNet. 2022. Available from: https://doi.org/10.13026/kk0v-r952.

Additionally, please cite the original publication:

Tan, S., Androz, G., Ortiz-Gagné, S., Chamseddine, A., Fecteau, P., Courville, A., Bengio, Y., & Cohen, J. P. (2021, October 21). Icentia11K: An Unsupervised Representation Learning Dataset for Arrhythmia Subtype Discovery. Computing in Cardiology Conference (CinC).

Please include the standard citation for PhysioNet: (show more options)
Goldberger, A., Amaral, L., Glass, L., Hausdorff, J., Ivanov, P. C., Mark, R., ... & Stanley, H. E. (2000). PhysioBank, PhysioToolkit, and PhysioNet: Components of a new research resource for complex physiologic signals. Circulation [Online]. 101 (23), pp. e215–e220.

##### Cite

APA | Goldberger, A., Amaral, L., Glass, L., Hausdorff, J., Ivanov, P. C., Mark, R., ... & Stanley, H. E. (2000). PhysioBank, PhysioToolkit, and PhysioNet: Components of a new research resource for complex physiologic signals. Circulation [Online]. 101 (23), pp. e215–e220.
MLA | Goldberger, A., et al. "PhysioBank, PhysioToolkit, and PhysioNet: Components of a new research resource for complex physiologic signals. Circulation [Online]. 101 (23), pp. e215–e220." (2000).
CHICAGO | Goldberger, A., L. Amaral, L. Glass, J. Hausdorff, P. C. Ivanov, R. Mark, J. E. Mietus, G. B. Moody, C. K. Peng, and H. E. Stanley. "PhysioBank, PhysioToolkit, and PhysioNet: Components of a new research resource for complex physiologic signals. Circulation [Online]. 101 (23), pp. e215–e220." (2000).
HARVARD | Goldberger, A., Amaral, L., Glass, L., Hausdorff, J., Ivanov, P.C., Mark, R., Mietus, J.E., Moody, G.B., Peng, C.K. and Stanley, H.E., 2000. PhysioBank, PhysioToolkit, and PhysioNet: Components of a new research resource for complex physiologic signals. Circulation [Online]. 101 (23), pp. e215–e220.
VANCOUVER | Goldberger A, Amaral L, Glass L, Hausdorff J, Ivanov PC, Mark R, Mietus JE, Moody GB, Peng CK, Stanley HE. PhysioBank, PhysioToolkit, and PhysioNet: Components of a new research resource for complex physiologic signals. Circulation [Online]. 101 (23), pp. e215–e220.

## Abstract

This is a dataset of continuous raw electrocardiogram (ECG) signals containing 11 thousand patients and 2 billion labelled beats. The signals were recorded with a 16-bit resolution at 250Hz with a fixed chest mounted single lead probe for up to 2 weeks. The average age of the patient is 62.2±17.4 years. 20 technologists annotated each beat's type (Normal, Premature Atrial Contraction, Premature Ventricular contraction) and rhythm (Normal Sinusal Rhythm, Atrial Fibrillation, Atrial Flutter).

## Background

Arrhythmia detection is presently performed by cardiologists or technologists familiar with ECG readings. Recently, supervised machine learning has been successfully applied to perform automated detection of many arrhythmias [1,2,3,4]. However, there may be ECG anomalies that warrant further investigation because they do not fit the morphology of presently known arrhythmia. We seek to use a data driven approach to finding these differences that cardiologists have anecdotally observed. Existing public ECG datasets include the the MIMIC-III Waveform Database and the ECG-ViEW II dataset [5,6]. Here we present Icentia11k, a dataset of continuous raw electrocardiogram (ECG) signals containing 11 thousand patients and 2 billion labelled beats

## Methods

Our data is collected by the CardioSTAT, a single-lead heart monitor device from Icentia [7]. The raw signals were recorded with a 16-bit resolution and sampled at 250Hz with the CardioSTAT in a modified lead 1 position. The wealth of data this provides us can allow us to improve on the techniques currently used by the medical industry to process days worth of ECG data, and perhaps to catch anomalous events earlier than currently possible.

The dataset is processed from data provided by 11,000 patients who used the CardioSTAT device predominantly in Ontario, Canada, from various medical centers. While the device captures ECG data for up to two weeks, the majority of the prescribed duration of wear was one week.

The data is analyzed by Icentia's team of 20 technologists who performed annotation using proprietary analysis tools. Initial beat detection is performed automatically and then a technologist analyses the record labelling beat and rhythm types performing a full disclosure analysis (i.e. they see the whole recording). Finally the analysis is approved by a senior technologist before making it to the dataset.

The ethics institutional review boards at the Université de Montréal approved the study and release of data (CERSES-19-065-D).

## Data Description

We segment each patient record into segments of 2 20 + 1 2^{20}+1 signal samples (≈70 minutes). This longer time context was informed by discussions with technologists: the context is useful for rhythm detection. We made it a power of two with a middle sample to allow for easier convolution stack parameterization. From this, we randomly select 50 of the segments and their respective labels from the list of segments. The goal here is to reduce the size of the dataset while maintaining a fair representation of each patient.

### Data structure

The data is structured into patients and segments.

#### Patient level (3-14 days)

At this level, the data can capture features which vary in a systematic way and not isolated events, like the placement of the probes or patient specific noise.

#### Segment level (1,048,577 int16 samples, approximately 1 hour)

A cardiologist can look at a specific segment and identify patterns which indicate a disease while ignoring noise from the signal such as a unique signal amplitude. Looking at trends in the segment help to correctly identify arrhythmia as half an hour provides the necessary context to observe the stress of a specific activity.

### Aggregate statistics

Aggregate statistics are shown below:

Statistic | # (units)
--- | ---
Number of patients | 11,000
Number of labeled beats | 2,774,054,987
Sample rate | 250Hz
Segment size | 2 20 + 1 2^{20}+1 = 1,048,577
Total number of segments | 541,794 (not all patients have enough for 50 segments)

Beats are annotated in ann.symbols at the R timepoint in the QRS complex. The timepoint in the rec.signal for each annotation is found in ann.sample Below shows the counts for beats over the entire dataset. There are also annotations with a '+' symbol which just mean there is a rhythm annotation (next table).

Symbol | Beat Description | Count
--- | --- | ---
N | Normal | 2,061,141,216
S | ESSV (PAC): Premature or ectopic supraventricular beat, premature atrial contraction | 19,346,728
V | ESV (PVC): Premature ventricular contraction, premature ventricular contraction | 17,203,041
Q | Undefined: Unclassifiable beat | 676,364,002

Rhythms are annotated in ann.aux_note at each timepoint. For example a normal sinusal rhythm will start with a '(N' annotation and then end with a ')' annotation. The entire sequence in between is annotated as a normal sinusal rhythm. Below are the counts of each annotated region which could be one beat or thousands.

Symbol | Rhythm Labels | Count
--- | --- | ---
(N ... ) | NSR (Normal sinusal rhythm) | 16,083,158
(AFIB ... ) | AFib (Atrial fibrillation) | 848,564
(AFL ... ) | AFlutter (Atrial flutter) | 313,251

Details on how the dataset is encoded into wfdb format are available on GitHub [8].

## Usage Notes

By releasing this dataset, we seek to enable the research community to develop better models for detection of arrhythmia and related heart disease. The dataset is described in more detail in our accompanying paper [9], which also describes our efforts to evaluation existing models for classification of arrhythmia. Code for working with the data, including executable notebooks, is available on GitHub [8].

### Example code

To look at patient 9000 and segment 0 the filename would be: p09/09000/p09000_s00 and it can loaded using wfdb as follows:

    import wfdb
    patient_id=9000
    segment_id=0
    start=2000
    length=1024
    filename = f'{data_path}/p0{str(patient_id)[:1]}/p{patient_id:05d}/p{patient_id:05d}_s{segment_id:02d}'
    rec = wfdb.rdrecord(filename, sampfrom=start, sampto=start+length)
    ann = wfdb.rdann(filename, "atr", sampfrom=start, sampto=start+length, shift_samps=True)
    wfdb.plot_wfdb(rec, ann, plot_sym=True, figsize=(15,4));

### Limitations

It should be noted that since the people who wear the device are patients, the dataset does not represent a true random sample of the global population. For one, the average age of the patient is 62.2±17.4 years of age. Furthermore, whereas the CardioSTAT can be worn by any patient, it is mostly used for third line exam, so the majority of records in the dataset exhibit arrhythmias. No particular effort has been done on patient selection except data collection has been conducted over years 2017 and 2018.

## Release Notes

Version 1.0: First release on PhysioNet. Prior to this release data was made available on AcademicTorrents [10].

## Ethics

The authors declare no ethics concerns. The ethics institutional review boards at the University of Montreal approved the study and release of data (#CERSES-19-065-D).

## Acknowledgements

We thank Leon Glass, Yannick Le Devehat, Germain Ethier, and Margaux Luck, Kris Sankaran, and Gabriele Prato for useful discussions. This work is partially funded by a grant from Icentia, Fonds de Recherche en Santé du Québec, and the Institut de valorisation des donnees (IVADO). This work utilized the supercomputing facilities managed by Compute Canada and Calcul Quebec. We thank AcademicTorrents.com for making data available for our research.

## Conflicts of Interest

None

## References

1. Hannun AY, Rajpurkar P, Haghpanahi M, Tison GH, Bourn C, Turakhia MP, Ng AY. Cardiologist-level arrhythmia detection and classification in ambulatory electrocardiograms using a deep neural network. Nature Medicine 2019
2. Yıldırım O, Pławiak P, Tan RS, Acharya UR. Arrhythmia detection using deep convolutional neural network with long duration ecg signals. Computers in biology and medicine 2018.
3. Minchole A, Rodriguez B. Artificial intelligence for the electrocardiogram. Nature Medicine 1 2019.
4. Porumb M, Iadanza E, Massaro S, Pecchia L. A convolutional neural network approach to detect congestive heart failure. Biomedical Signal Processing and Control 2020.
5. Johnson, A., Pollard, T., & Mark, R. (2016). MIMIC-III Clinical Database (version 1.4). PhysioNet. https://doi.org/10.13026/C2XW26.
6. Kim YG, Shin D, Park MY, Lee S, Jeon MS, Yoon D, Park RW. ECG-ViEW II, a freely accessible electrocardiogram database. PloS one 2017.
7. Icentia website. https://www.icentia.com/
8. Icentia11k project on GitHub. https://github.com/shawntan/icentia-ecg/tree/master/physionet
9. Tan, S., Androz, G., Ortiz-Gagné, S., Chamseddine, A., Fecteau, P., Courville, A., Bengio, Y., & Cohen, J. P. (2021, October 21). Icentia11K: An Unsupervised Representation Learning Dataset for Arrhythmia Subtype Discovery. Computing in Cardiology Conference (CinC). https://www.cinc.org/2021/Program/accepted/229_Preprint.pdf
10. Icentia11k Dataset on Academic Torrents. https://academictorrents.com/details/af04abfe9a3c96b30e5dd029eb185e19a7055272

##### Share

##### Access

Access Policy:
Anyone can access the files, as long as they conform to the terms of the specified license.

License (for files):
Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International Public License

##### Discovery

DOI:
https://doi.org/10.13026/kk0v-r952

Topics:
representation learning ecg

Project Website:
https://github.com/shawntan/icentia-ecg

##### Corresponding Author

You must be logged in to view the contact information.

## Files

Total uncompressed size: 1.1 TB.

##### Access the files

- Download the ZIP file (188.3 GB)
- Download the files using your terminal:

      wget -r -N -c -np https://physionet.org/files/icentia11k-continuous-ecg/1.0/

Visualize waveforms

Folder Navigation: <base>/p06/p06073

Name | Size | Modified
--- | --- | ---
Parent Directory |  |
RECORDS (download) | 550 B | 2022-02-13
p06073_s00.atr (download) | 36.9 KB | 2022-02-13
p06073_s00.dat (download) | 2 MB | 2022-02-13
p06073_s00.hea (download) | 87 B | 2022-02-13
p06073_s01.atr (download) | 43.0 KB | 2022-02-13
p06073_s01.dat (download) | 2 MB | 2022-02-13
p06073_s01.hea (download) | 86 B | 2022-02-13
p06073_s02.atr (download) | 36.8 KB | 2022-02-13
p06073_s02.dat (download) | 2 MB | 2022-02-13
p06073_s02.hea (download) | 85 B | 2022-02-13
p06073_s03.atr (download) | 35.4 KB | 2022-02-13
p06073_s03.dat (download) | 2 MB | 2022-02-13
p06073_s03.hea (download) | 87 B | 2022-02-13
p06073_s04.atr (download) | 43.1 KB | 2022-02-13
p06073_s04.dat (download) | 2 MB | 2022-02-13
p06073_s04.hea (download) | 87 B | 2022-02-13
p06073_s05.atr (download) | 41.4 KB | 2022-02-13
p06073_s05.dat (download) | 2 MB | 2022-02-13
p06073_s05.hea (download) | 87 B | 2022-02-13
p06073_s06.atr (download) | 35.3 KB | 2022-02-13
p06073_s06.dat (download) | 2 MB | 2022-02-13
p06073_s06.hea (download) | 87 B | 2022-02-13
p06073_s07.atr (download) | 37.3 KB | 2022-02-13
p06073_s07.dat (download) | 2 MB | 2022-02-13
p06073_s07.hea (download) | 86 B | 2022-02-13
p06073_s08.atr (download) | 39.6 KB | 2022-02-13
p06073_s08.dat (download) | 2 MB | 2022-02-13
p06073_s08.hea (download) | 86 B | 2022-02-13
p06073_s09.atr (download) | 43.7 KB | 2022-02-13
p06073_s09.dat (download) | 2 MB | 2022-02-13
p06073_s09.hea (download) | 87 B | 2022-02-13
p06073_s10.atr (download) | 40.8 KB | 2022-02-13
p06073_s10.dat (download) | 2 MB | 2022-02-13
p06073_s10.hea (download) | 87 B | 2022-02-13
p06073_s11.atr (download) | 44.8 KB | 2022-02-13
p06073_s11.dat (download) | 2 MB | 2022-02-13
p06073_s11.hea (download) | 87 B | 2022-02-13
p06073_s12.atr (download) | 35.0 KB | 2022-02-13
p06073_s12.dat (download) | 2 MB | 2022-02-13
p06073_s12.hea (download) | 87 B | 2022-02-13
p06073_s13.atr (download) | 37.7 KB | 2022-02-13
p06073_s13.dat (download) | 2 MB | 2022-02-13
p06073_s13.hea (download) | 87 B | 2022-02-13
p06073_s14.atr (download) | 41.7 KB | 2022-02-13
p06073_s14.dat (download) | 2 MB | 2022-02-13
p06073_s14.hea (download) | 86 B | 2022-02-13
p06073_s15.atr (download) | 39.8 KB | 2022-02-13
p06073_s15.dat (download) | 2 MB | 2022-02-13
p06073_s15.hea (download) | 86 B | 2022-02-13
p06073_s16.atr (download) | 35.5 KB | 2022-02-13
p06073_s16.dat (download) | 2 MB | 2022-02-13
p06073_s16.hea (download) | 87 B | 2022-02-13
p06073_s17.atr (download) | 37.3 KB | 2022-02-13
p06073_s17.dat (download) | 2 MB | 2022-02-13
p06073_s17.hea (download) | 87 B | 2022-02-13
p06073_s18.atr (download) | 40.2 KB | 2022-02-13
p06073_s18.dat (download) | 2 MB | 2022-02-13
p06073_s18.hea (download) | 87 B | 2022-02-13
p06073_s19.atr (download) | 36.9 KB | 2022-02-13
p06073_s19.dat (download) | 2 MB | 2022-02-13
p06073_s19.hea (download) | 87 B | 2022-02-13
p06073_s20.atr (download) | 37.6 KB | 2022-02-13
p06073_s20.dat (download) | 2 MB | 2022-02-13
p06073_s20.hea (download) | 86 B | 2022-02-13
p06073_s21.atr (download) | 33.3 KB | 2022-02-13
p06073_s21.dat (download) | 2 MB | 2022-02-13
p06073_s21.hea (download) | 85 B | 2022-02-13
p06073_s22.atr (download) | 36.4 KB | 2022-02-13
p06073_s22.dat (download) | 2 MB | 2022-02-13
p06073_s22.hea (download) | 87 B | 2022-02-13
p06073_s23.atr (download) | 36.3 KB | 2022-02-13
p06073_s23.dat (download) | 2 MB | 2022-02-13
p06073_s23.hea (download) | 86 B | 2022-02-13
p06073_s24.atr (download) | 40.0 KB | 2022-02-13
p06073_s24.dat (download) | 2 MB | 2022-02-13
p06073_s24.hea (download) | 86 B | 2022-02-13
p06073_s25.atr (download) | 37.8 KB | 2022-02-13
p06073_s25.dat (download) | 2 MB | 2022-02-13
p06073_s25.hea (download) | 85 B | 2022-02-13
p06073_s26.atr (download) | 41.0 KB | 2022-02-13
p06073_s26.dat (download) | 2 MB | 2022-02-13
p06073_s26.hea (download) | 87 B | 2022-02-13
p06073_s27.atr (download) | 40.7 KB | 2022-02-13
p06073_s27.dat (download) | 2 MB | 2022-02-13
p06073_s27.hea (download) | 86 B | 2022-02-13
p06073_s28.atr (download) | 39.8 KB | 2022-02-13
p06073_s28.dat (download) | 2 MB | 2022-02-13
p06073_s28.hea (download) | 86 B | 2022-02-13
p06073_s29.atr (download) | 33.9 KB | 2022-02-13
p06073_s29.dat (download) | 2 MB | 2022-02-13
p06073_s29.hea (download) | 86 B | 2022-02-13
p06073_s30.atr (download) | 40.9 KB | 2022-02-13
p06073_s30.dat (download) | 2 MB | 2022-02-13
p06073_s30.hea (download) | 87 B | 2022-02-13
p06073_s31.atr (download) | 41.7 KB | 2022-02-13
p06073_s31.dat (download) | 2 MB | 2022-02-13
p06073_s31.hea (download) | 86 B | 2022-02-13
p06073_s32.atr (download) | 40.3 KB | 2022-02-13
p06073_s32.dat (download) | 2 MB | 2022-02-13
p06073_s32.hea (download) | 87 B | 2022-02-13
p06073_s33.atr (download) | 40.3 KB | 2022-02-13
p06073_s33.dat (download) | 2 MB | 2022-02-13
p06073_s33.hea (download) | 87 B | 2022-02-13
p06073_s34.atr (download) | 39.0 KB | 2022-02-13
p06073_s34.dat (download) | 2 MB | 2022-02-13
p06073_s34.hea (download) | 87 B | 2022-02-13
p06073_s35.atr (download) | 36.7 KB | 2022-02-13
p06073_s35.dat (download) | 2 MB | 2022-02-13
p06073_s35.hea (download) | 86 B | 2022-02-13
p06073_s36.atr (download) | 42.0 KB | 2022-02-13
p06073_s36.dat (download) | 2 MB | 2022-02-13
p06073_s36.hea (download) | 87 B | 2022-02-13
p06073_s37.atr (download) | 40.6 KB | 2022-02-13
p06073_s37.dat (download) | 2 MB | 2022-02-13
p06073_s37.hea (download) | 85 B | 2022-02-13
p06073_s38.atr (download) | 40.9 KB | 2022-02-13
p06073_s38.dat (download) | 2 MB | 2022-02-13
p06073_s38.hea (download) | 87 B | 2022-02-13
p06073_s39.atr (download) | 40.5 KB | 2022-02-13
p06073_s39.dat (download) | 2 MB | 2022-02-13
p06073_s39.hea (download) | 87 B | 2022-02-13
p06073_s40.atr (download) | 39.5 KB | 2022-02-13
p06073_s40.dat (download) | 2 MB | 2022-02-13
p06073_s40.hea (download) | 87 B | 2022-02-13
p06073_s41.atr (download) | 40.7 KB | 2022-02-13
p06073_s41.dat (download) | 2 MB | 2022-02-13
p06073_s41.hea (download) | 87 B | 2022-02-13
p06073_s42.atr (download) | 40.1 KB | 2022-02-13
p06073_s42.dat (download) | 2 MB | 2022-02-13
p06073_s42.hea (download) | 87 B | 2022-02-13
p06073_s43.atr (download) | 39.6 KB | 2022-02-13
p06073_s43.dat (download) | 2 MB | 2022-02-13
p06073_s43.hea (download) | 87 B | 2022-02-13
p06073_s44.atr (download) | 42.0 KB | 2022-02-13
p06073_s44.dat (download) | 2 MB | 2022-02-13
p06073_s44.hea (download) | 87 B | 2022-02-13
p06073_s45.atr (download) | 37.5 KB | 2022-02-13
p06073_s45.dat (download) | 2 MB | 2022-02-13
p06073_s45.hea (download) | 86 B | 2022-02-13
p06073_s46.atr (download) | 41.6 KB | 2022-02-13
p06073_s46.dat (download) | 2 MB | 2022-02-13
p06073_s46.hea (download) | 87 B | 2022-02-13
p06073_s47.atr (download) | 40.3 KB | 2022-02-13
p06073_s47.dat (download) | 2 MB | 2022-02-13
p06073_s47.hea (download) | 87 B | 2022-02-13
p06073_s48.atr (download) | 36.0 KB | 2022-02-13
p06073_s48.dat (download) | 2 MB | 2022-02-13
p06073_s48.hea (download) | 86 B | 2022-02-13
p06073_s49.atr (download) | 36.2 KB | 2022-02-13
p06073_s49.dat (download) | 2 MB | 2022-02-13
p06073_s49.hea (download) | 87 B | 2022-02-13